@@ -20,6 +20,7 @@ SHOULD include dedicated exception logging.
 """
 
 from oslo.config import cfg
+import six
 
 from tuskar.openstack.common.gettextutils import _  # noqa
 from tuskar.openstack.common import log as logging
@@ -110,7 +111,7 @@ class TuskarException(Exception):
         if self.__class__.__name__.endswith('_Remote'):
             return self.args[0]
         else:
-            return unicode(self)
+            return six.text_type(self)
 
 
 class NotAuthorized(TuskarException):
@@ -173,10 +174,6 @@ class ConfigNotFound(TuskarException):
     message = _("Could not find config at %(path)s")
 
 
-class InvalidHeatTemplate(TuskarException):
-    message = _("Validation of the Heat Template failed.")
-
-
 class StackNotFound(NotFound):
     message = _("The Stack for this Overcloud can't be found.")
 
@@ -185,9 +182,21 @@ class StackAlreadyCreated(DuplicateEntry):
     message = _("The Stack for this Overcloud already exists.")
 
 
-class HeatTemplateUpdateFailed(TuskarException):
-    message = _("The Heat template failed to update.")
-
-
 class HeatTemplateCreateFailed(TuskarException):
     message = _("The Heat template failed to create.")
+
+
+class HeatTemplateValidateFailed(TuskarException):
+    message = _("Validation of the Heat template failed.")
+
+
+class HeatStackUpdateFailed(TuskarException):
+    message = _("The Heat stack failed to update.")
+
+
+class HeatStackCreateFailed(TuskarException):
+    message = _("The Heat stack failed to update.")
+
+
+class HeatStackDeleteFailed(TuskarException):
+    message = _("The Heat stack failed to delete.")
